@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.18';
+our $VERSION = '1.19';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(
     layout checkerboard scroll
     chess checkers conway sudoku
     calculator calendar banner maze
-    beadwork animate list
+    beadwork list
 );
 
 use HTML::AutoTag;
@@ -39,7 +39,6 @@ sub sudoku          { Spreadsheet::HTML::Presets::Sudoku::sudoku(   @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard(     @_ ) }
 sub calendar        { Spreadsheet::HTML::Presets::calendar(         @_ ) }
 sub scroll          { Spreadsheet::HTML::Presets::Scroll::scroll(   @_ ) }
-sub animate         { Spreadsheet::HTML::Presets::Scroll::animate(  @_ ) }
 sub maze            { Spreadsheet::HTML::Presets::maze(             @_ ) }
 sub banner          { Spreadsheet::HTML::Presets::banner(           @_ ) }
 sub beadwork        { Spreadsheet::HTML::Presets::Beadwork::beadwork( @_ ) }
@@ -88,11 +87,6 @@ sub generate {
         $args{data} = [ CORE::reverse @{ _transpose( $args{data} ) }];
     }
 
-    if ($args{animate}) {
-        warn "animate is deprecated, use scroll instead\n";
-        $args{scroll} = $args{animate};
-    }
-
     if ($args{scroll}) {
         my ($js, %new_args) = Spreadsheet::HTML::Presets::Scroll::scroll(
             %args,
@@ -970,10 +964,6 @@ Generate banners via Text::FIGlet.
 
 Scroll table cell foregrounds and backgrounds.
 
-=item * C<animate( fgdirection, fx, fy, bgdirection, bx, by, interval, jquery, %params )>
-
-Deprecated. Use C<scroll()> instead.
-
 =item * C<calendar( month, year, today, -day, %params )>
 
 Generate calendars.
