@@ -229,7 +229,8 @@ sub calendar {
         
         push @cal_args, ( data => \@flat );
 
-        $args->{ '-' . Time::Piece->new->mday } = $args->{today};
+        my $mday = '-' . Time::Piece->new->mday;
+        $args->{$mday} = exists $args->{$mday} ? $args->{$mday} : $args->{today};
         my %day_args = map {($_ => $args->{$_})} grep /^-\d+$/, keys %$args;
         for (keys %day_args) {
             my $day = abs($_);
@@ -401,7 +402,7 @@ will silently fail and produce no banner.
 
 Generates a static calendar. Defaults to current month and year.
 
-  calendar( month => 7, year, 2012 )
+  calendar( month => 7, year => 2012 )
 
 Mark a day of the month like so:
 
